"""
CWMS is a variant of the TRIPS system. It is a general purpose
natural language understanding system with applications in
world modeling. For more information, see:
http://trips.ihmc.us/parser/cgi/cwmsreader
"""
from .api import process_text, process_ekb, process_ekb_file
